==> azure_svc_mixedreality-0.2.0.crate: azure_svc_mixedreality-0.2.0/README.md <==
# azure_svc_mixedreality crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/mixedreality/data-plane/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-01-01`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-0.3-preview.0` has 3 operations from 1 API versions: `0.3-preview.0`. Use crate feature `package-0_3-preview_0` to enable. The operations will be in the `package_0_3_preview_0` module.
- `package-0.2-preview.1` has 3 operations from 1 API versions: `0.2-preview.1`. Use crate feature `package-0_2-preview_1` to enable. The operations will be in the `package_0_2_preview_1` module.
- `package-2021-01-01` has 8 operations from 1 API versions: `2021-01-01`. Use crate feature `package-2021-01-01` to enable. The operations will be in the `package_2021_01_01` module.
- `package-0.2-preview.0` has 3 operations from 1 API versions: `0.2-preview.0`. Use crate feature `package-0_2-preview_0` to enable. The operations will be in the `package_0_2_preview_0` module.
- `package-2021-01-01-preview` has 8 operations from 1 API versions: `2021-01-01-preview`. Use crate feature `package-2021-01-01-preview` to enable. The operations will be in the `package_2021_01_01_preview` module.
- `package-2019-02-28-preview` has 1 operations from 1 API versions: `2019-02-28-preview`. Use crate feature `package-2019-02-28-preview` to enable. The operations will be in the `package_2019_02_28_preview` module.

==> azure_svc_mixedreality-0.3.0.crate: azure_svc_mixedreality-0.3.0/README.md <==
# azure_svc_mixedreality crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/mixedreality/data-plane/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-01-01`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-0.3-preview.1` has 3 operations from 1 API versions: `0.3-preview.1`. Use crate feature `package-0_3-preview_1` to enable. The operations will be in the `package_0_3_preview_1` module.
- `package-0.3-preview.0` has 3 operations from 1 API versions: `0.3-preview.0`. Use crate feature `package-0_3-preview_0` to enable. The operations will be in the `package_0_3_preview_0` module.
- `package-0.2-preview.1` has 3 operations from 1 API versions: `0.2-preview.1`. Use crate feature `package-0_2-preview_1` to enable. The operations will be in the `package_0_2_preview_1` module.
- `package-2021-01-01` has 8 operations from 1 API versions: `2021-01-01`. Use crate feature `package-2021-01-01` to enable. The operations will be in the `package_2021_01_01` module.
- `package-0.2-preview.0` has 3 operations from 1 API versions: `0.2-preview.0`. Use crate feature `package-0_2-preview_0` to enable. The operations will be in the `package_0_2_preview_0` module.
- `package-2021-01-01-preview` has 8 operations from 1 API versions: `2021-01-01-preview`. Use crate feature `package-2021-01-01-preview` to enable. The operations will be in the `package_2021_01_01_preview` module.
- `package-2019-02-28-preview` has 1 operations from 1 API versions: `2019-02-28-preview`. Use crate feature `package-2019-02-28-preview` to enable. The operations will be in the `package_2019_02_28_preview` module.
